@@ -1,7 +1,7 @@
 """Interpolating string formatter. """
 
 import string, inspect, sys, itertools
-from otherstuf import chainstuf  
+from stuf import chainstuf  
 from options import Options, OptionsContext
 import six
 if six.PY3:
@@ -107,7 +107,6 @@ def _sprintf(arg, caller, override=None):
 
 ### Core Say class
 
-DEFAULT_FILES = [ stdout]
 
 class Say(object):
     """
@@ -120,7 +119,7 @@ class Say(object):
         encoding=None if six.PY3 else 'utf-8',
                             # character encoding for output (needed on Python 2, not 3)
         encoded=None,       # character encoding to return
-        files=None,         # where is output headed? a list of write() able objects
+        files= [stdout],    # where is output headed? a list of write() able objects
                             # NB Set to [stdout] but in way that gets around stuf bug
         wrap=None,          # column to wrap text to, if any
         sep=' ',            # separate args with this (Python print function compatible)
@@ -129,7 +128,6 @@ class Say(object):
         retvalue=False,     # should return the value of the formatted string?
         _callframe=None,    # frome from which the caller was calling
     )
-    options.files = DEFAULT_FILES # to get around a bug in stuf
     
     options.magic(
         indent = lambda v, cur: cur.indent + int(v) if isinstance(v, str) else v
